Crate fnir

Crate fnir 

Modules

algebra
Implements various abstract algebra abstractions. Here, Commutative* are traits such that the output of operations is self, whereas Commuting* the output is T.
quadrature
Numerical quadrature rules. To use a (generic, non-existent) rule Rule, one must first call Rule::new(), and then either use Rule::nint or Rule::integrate depending if rule modifications are desired or not.

Enums

IntegrationError
Various errors that can occur while integrating

Traits

Integral

Type Aliases

Result
Internal result type